@@ -21,8 +21,8 @@ class ml3:
 
     #LOG,INFO,WARN,ERROR,
     def intro():
-    print("这是TechYoung课程的机器学习辅助工具包")
-    return True
+        print("这是TechYoung课程的机器学习辅助工具包")
+        return True
 
     """
     data必须是dataframe,column_name是特征名字
@@ -46,4 +46,11 @@ class ml3:
         datetime_str = time.strftime("%Y%m%d%H%M%S",time.localtime())
         file_name = hashlib.md5(datetime_str.encode(encoding='UTF-8')).hexdigest()
         plt.savefig(file_name + ".png", dpi=100)
-        return True 
+        return True
+
+def main():
+    ml3.intro()
+
+if __name__ == '__main__':
+     main()
+
